@@ -1,4 +1,4 @@
-/*  $Id: main-window.cpp,v 1.12 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: main-window.cpp,v 1.13 2005/04/23 01:06:08 sarrazip Exp $
     main-window.cpp - Input and conjugation window
 
     verbiste - French conjugation system
@@ -495,6 +495,18 @@ processText(const string &utf8UserText)
 	gtk_widget_show_all(GTK_WIDGET(rp->notebookPage));
     }
 
+
+
+    /*  PATCH: without this hack, a 2-page notebook has its first tab
+	active but showing the contents of the second page.  This can
+	be tested by entering "parais", which corresponds to the two
+	infinitives "paratre" and "parer".
+    */
+    if (gtk_notebook_get_n_pages(GTK_NOTEBOOK(resultNotebook)) > 1)
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(resultNotebook), 1);
+
+
+
     gtk_notebook_set_current_page(GTK_NOTEBOOK(resultNotebook), 0);
 }
 
